Example: Hello World — XlsxWriter Documentation

### Navigation

- index
- next |
- previous |
- XlsxWriter Documentation »
- Examples »

# Example: Hello World

The simplest possible spreadsheet. This is a good place to start to see if the XlsxWriter module is installed correctly.

    ##############################################################################
    #
    # A hello world spreadsheet using the XlsxWriter Python module.
    #
    # Copyright 2013, John McNamara, jmcnamara@cpan.org
    #
    from xlsxwriter.workbook import Workbook

    workbook = Workbook('hello_world.xlsx')
    worksheet = workbook.add_worksheet()

    worksheet.write('A1', 'Hello world')

    workbook.close()

### Navigation

- index
- next |
- previous |
- XlsxWriter Documentation »
- Examples »